/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.model;

import static org.conqat.lib.commons.collections.CollectionUtils.asUnmodifiable;

import java.util.ArrayList;
import java.util.List;

/**
 * Main class of the spider chart model.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 74F497F82BD13B18035A011ACC09B01F
 */
public final class SpiderChart {
	/** The axes contained in this chart. */
	private List<AxisBase> axes = new ArrayList<>();
	/** The data sets contained in this chart. */
	private List<DataSeries> dataSeries = new ArrayList<DataSeries>();
	/** The title of the spider chart. */
	private String title;
	/** The label of the legend. */
	private String legendLabel;

	/** Adds the given data series. */
	public void addData(DataSeries d) {
		dataSeries.add(d);
	}

	/** Adds the given axis. */
	public void addAxis(AxisBase a) {
		axes.add(a);
	}

	/** Sets title. */
	public void setTitle(String title) {
		this.title = title;
	}

	/** Sets legendLabel. */
	public void setLegendLabel(String legendLabel) {
		this.legendLabel = legendLabel;
	}

	/**
	 * Validates the chart by checking if all data series provide a non-null value for each axis and
	 * that this value is within the axis minimum an maximum values..
	 */
	public boolean checkDataValidity() {
		for(DataSeries d : dataSeries) {
			for(AxisBase a : axes) {
				if(d.getAxisValue(a) == null) {
					return false;
				}
				if(!a.isValidValue(d.getAxisValue(a))) {
					return false;
				}
			}
		}
		return true;
	}

	/** Returns the unmodifiable list of axes. */
	public List<AxisBase> getAxes() {
		return asUnmodifiable(axes);
	}

	/** Returns the unmodifiable list of data series. */
	public List<DataSeries> getDataSeries() {
		return asUnmodifiable(dataSeries);
	}

	/** Returns the legend label. */
	public String getLegendLabel() {
		return legendLabel;
	}

	/** Returns title. */
	public String getTitle() {
		return title;
	}
}
